[flashrom] [PATCH 4a/10] 4BA: W25Q256.V declaration update to work using Extended Address.Register

Boris Baykov dev at borisbaykov.com
Sun Jan 11 00:21:26 CET 2015


The 4a patch is made to show how can you define chips with access via
Extebded Address Register. This patch is fully working but not required.

Patched files
-------------
flashchips.c 
+ modified definition of Winbond W25Q256BV/W25Q256FV chips


Signed-off-by: Boris Baykov <dev at borisbaykov.com>, Russia, Jan 2014
---
diff -U 5 -N ./flashrom/flashchips.c ./flashrom-1868-4ba-4a/flashchips.c
--- ./flashrom/flashchips.c     2015-01-11 02:03:38.000000000 +0300
+++ ./flashrom-1868-4ba-4a/flashchips.c 2015-01-10 19:23:32.000000000 +0300
@@ -13329,32 +13329,33 @@
                .total_size     = 32768,
                .page_size      = 256,
                /* supports SFDP */
                /* OTP: 1024B total, 256B reserved; read 0x48; write 0x42, erase 0x44, read ID 0x4B */
                /* FOUR_BYTE_ADDR: supports 4-bytes addressing mode */
-               .feature_bits   = FEATURE_WRSR_WREN | FEATURE_OTP | FEATURE_4BA_SUPPORT,
+               .feature_bits   = FEATURE_WRSR_WREN | FEATURE_OTP | FEATURE_4BA_SUPPORT 
+                                 | FEATURE_4BA_EXTENDED_ADDR_REG,
                .four_bytes_addr_funcs = 
                {
-                       .enter_4ba = spi_enter_4ba_b7_we, /* enter 4-bytes addressing mode by CMD B7 + WREN */
-                       .read_nbyte = spi_nbyte_read_4ba, /* read from 4-bytes addressing mode */
-                       .program_byte = spi_byte_program_4ba, /* write from 4-bytes addressing mode */
-                       .program_nbyte = spi_nbyte_program_4ba /* write from 4-bytes addressing mode */
+                       .enter_4ba = NULL, /* no need to enter 4-bytes addressing mode */
+                       .read_nbyte = spi_nbyte_read_4ba_ereg, /* read using ext.addr.reg from 3-bytes mode */
+                       .program_byte = spi_byte_program_4ba_ereg, /* write using ext.addr.reg from 3-bytes mode */
+                       .program_nbyte = spi_nbyte_program_4ba_ereg /* write using ext.addr.reg from 3-bytes mode */
                },
                .tested         = TEST_OK_PREW,
                .probe          = probe_spi_rdid,
                .probe_timing   = TIMING_ZERO,
                .block_erasers  =
                {
                        {
                                .eraseblocks = { {4 * 1024, 8192} },
-                               .block_erase = spi_block_erase_20_4ba, /* erases 4k from 4-bytes addressing mode */
+                               .block_erase = spi_block_erase_20_4ba_ereg, /* erases 4k using ext.addr.reg from 3-bytes mode */
                        }, {
                                .eraseblocks = { {32 * 1024, 1024} },
-                               .block_erase = spi_block_erase_52_4ba, /* erases 32k from 4-bytes addressing mode */
+                               .block_erase = spi_block_erase_52_4ba_ereg, /* erases 32k using ext.addr.reg from 3-bytes mode */
                        }, {
                                .eraseblocks = { {64 * 1024, 512} },
-                               .block_erase = spi_block_erase_d8_4ba, /* erases 64k from 4-bytes addressing mode */
+                               .block_erase = spi_block_erase_d8_4ba_ereg, /* erases 64k using ext.addr.reg from 3-bytes mode */
                        }, {
                                .eraseblocks = { {32 * 1024 * 1024, 1} },
                                .block_erase = spi_block_erase_60,
                        }, {
                                .eraseblocks = { {32 * 1024 * 1024, 1} },
-------------- next part --------------
A non-text attachment was scrubbed...
Name: flashrom-r1868-4ba-part-4a.patch.tar.bz2
Type: application/octet-stream
Size: 1198 bytes
Desc: not available
URL: <http://www.flashrom.org/pipermail/flashrom/attachments/20150111/93b35bf7/attachment.obj>


More information about the flashrom mailing list